function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import * as React from 'react';
import { View, StyleSheet } from 'react-native';
import { useState } from 'react';
import Svg, { ClipPath, Defs, Path } from 'react-native-svg';
import { getSvgPath } from 'figma-squircle';
import { useId } from "@reach/auto-id";

function SquircleView({
  squircleParams,
  children,
  ...rest
}) {
  return /*#__PURE__*/React.createElement(View, rest, /*#__PURE__*/React.createElement(SquircleBackground, squircleParams), children);
}

function SquircleBackground({
  cornerRadius = 0,
  topLeftCornerRadius,
  topRightCornerRadius,
  bottomRightCornerRadius,
  bottomLeftCornerRadius,
  cornerSmoothing,
  fillColor = '#000',
  strokeColor = '#000',
  strokeWidth = 0
}) {
  const squircleId = useId();
  return /*#__PURE__*/React.createElement(Rect, {
    style: StyleSheet.absoluteFill
  }, ({
    width,
    height
  }) => {
    const squirclePath = getSvgPath({
      width,
      height,
      cornerSmoothing,
      cornerRadius,
      topLeftCornerRadius,
      topRightCornerRadius,
      bottomRightCornerRadius,
      bottomLeftCornerRadius
    });
    const hasStroke = strokeWidth > 0;

    if (!hasStroke) {
      return /*#__PURE__*/React.createElement(Svg, {
        width: "100%",
        height: "100%",
        viewBox: `0 0 ${width} ${height}`
      }, /*#__PURE__*/React.createElement(Path, {
        d: squirclePath,
        fill: fillColor
      }));
    } else {
      // Since SVG doesn't support inner stroke, we double the stroke width
      // and remove the outer half with clipPath
      const clipPathId = `clip-${squircleId}`;
      return /*#__PURE__*/React.createElement(Svg, {
        width: "100%",
        height: "100%",
        viewBox: `0 0 ${width} ${height}`
      }, /*#__PURE__*/React.createElement(Defs, null, /*#__PURE__*/React.createElement(ClipPath, {
        id: clipPathId
      }, /*#__PURE__*/React.createElement(Path, {
        d: squirclePath
      }))), /*#__PURE__*/React.createElement(Path, {
        clipPath: `url(#${clipPathId})`,
        d: squirclePath,
        fill: fillColor,
        stroke: strokeColor,
        strokeWidth: strokeWidth * 2
      }));
    }
  });
} // Inspired by https://reach.tech/rect/


function Rect({
  children,
  ...rest
}) {
  const [rect, setRect] = useState(null);
  return /*#__PURE__*/React.createElement(View, _extends({}, rest, {
    onLayout: e => {
      setRect({
        width: e.nativeEvent.layout.width,
        height: e.nativeEvent.layout.height
      });
    }
  }), rect ? children(rect) : null);
}

export { SquircleView, getSvgPath };
//# sourceMappingURL=index.js.map